;; Generated package description from geiser-gambit.el  -*- no-byte-compile: t -*-
(define-package "geiser-gambit" "0.18.1.0.20220208.135610" "Gambit's implementation of the geiser protocols" '((emacs "26.1") (geiser "0.18")) :commit "381d74ca5059b44fe3d8b5daf42214019c6d1a88" :maintainer '("Jose A Ortega Ruiz" . "jao@gnu.org") :keywords '("languages" "gambit" "scheme" "geiser") :url "https://gitlab.com/emacs-geiser/gambit")
